pub struct Limits {
pub max_records: usize,
pub max_encrypted_blob_size: usize,
pub max_metadata_string_bytes: usize,
pub max_decompressed_blob_size: usize,
}Expand description
Parser limits for AU3 record extraction.
Fields
max_records: usizeMaximum number of records to parse.
max_encrypted_blob_size: usizeMaximum encrypted blob size accepted for a single record.
max_metadata_string_bytes: usizeMaximum decoded metadata string length in bytes.
max_decompressed_blob_size: usizeMaximum decompressed blob size accepted for a single record.