pub struct RecordParseReport { /* private fields */ }Expand description
Result of tolerant AU3 record parsing.
Implementations
Sourceimpl RecordParseReport
impl RecordParseReport
Sourcepub fn into_records(self) -> Vec<Record>
pub fn into_records(self) -> Vec<Record>
Sourcepub const fn diagnostic(&self) -> Option<RecordParseDiagnostic>
pub const fn diagnostic(&self) -> Option<RecordParseDiagnostic>
Returns the diagnostic describing why parsing stopped, when present.
Returns
Some with a RecordParseDiagnostic when parsing stopped on a failure or
limit, or None when the stream ended cleanly at a non-FILE marker.