Error

Struct Error 

pub struct Error { /* private fields */ }
Crate-wide error type.

Implementations

Source

impl Error

pub const fn not_recognized() -> Self

Creates a not-recognized error.

Returns

An Error wrapping RecognitionFailure::NotRecognized.

pub const fn unsupported_encoding() -> Self

Creates an unsupported-encoding error.

Returns

An Error wrapping RecognitionFailure::UnsupportedEncoding.

pub const fn truncated() -> Self

Creates a truncated-input error.

Returns

An Error wrapping RecognitionFailure::Truncated.

pub const fn malformed_container() -> Self

Creates a malformed-container error.

Returns

An Error wrapping RecognitionFailure::MalformedContainer.

pub const fn limit_exceeded() -> Self

Creates a limit-exceeded error.

Returns

An Error wrapping RecognitionFailure::LimitExceeded.

pub const fn crypto_mismatch() -> Self

Creates a crypto-mismatch error.

Returns

An Error wrapping RecognitionFailure::CryptoMismatch.

pub const fn compression_error() -> Self

Creates a decompression error.

Returns

An Error wrapping RecognitionFailure::CompressionError.

pub const fn token_error() -> Self

Creates a token-decoding error.

Returns

An Error wrapping RecognitionFailure::TokenError.

pub const fn recognition_failure(&self) -> Option<RecognitionFailure>

Returns the recognition failure when this error represents one.

Returns

Some with the wrapped RecognitionFailure; currently every Error carries one, so this never returns None.

Examples found in repository?
examples/dump.rs (line 37)
7fn main() -> ExitCode {
8    let mut args = env::args_os();
9    let _program = args.next();
10    let mut path = None;
11    for arg in args {
12        if path.is_none() {
13            path = Some(arg);
14        } else {
15            eprintln!("usage: dump <autoit-exe-or-a3x>");
16            return ExitCode::FAILURE;
17        }
18    }
19    let Some(path) = path else {
20        eprintln!("usage: dump <autoit-exe-or-a3x>");
21        return ExitCode::FAILURE;
22    };
23
24    let data = match fs::read(&path) {
25        Ok(data) => data,
26        Err(err) => {
27            eprintln!("failed to read input: {err}");
28            return ExitCode::FAILURE;
29        }
30    };
31
32    match AutoItBinary::try_parse(&data) {
33        Ok(binary) => {
34            print_text(&binary);
35            ExitCode::SUCCESS
36        }
37        Err(err) if err.recognition_failure() == Some(RecognitionFailure::NotRecognized) => {
38            eprintln!("not recognized as AutoIt");
39            ExitCode::FAILURE
40        }
41        Err(err) => {
42            eprintln!("failed to parse AutoIt payload: {err}");
43            ExitCode::FAILURE
44        }
45    }
46}