StringFinding

Struct StringFinding 

pub struct StringFinding { /* private fields */ }
A raw string found in recovered bytes.

Implementations

Source

impl StringFinding

pub const fn record_index(&self) -> usize

Returns the source record index.

Returns

The index of the Record this string was extracted from.

Examples found in repository?
examples/dump.rs (line 296)
291fn print_strings(strings: &[StringFinding]) {
292    section(&format!("strings ({})", strings.len()));
293    for found in strings {
294        println!(
295            "  record #{} offset {} {:?}: {}",
296            found.record_index(),
297            found.offset(),
298            found.encoding(),
299            escape_inline(found.value())
300        );
301    }
302}
pub const fn offset(&self) -> usize

Returns byte offset inside the record payload.

Returns

The byte offset within the record payload where the string begins.

Examples found in repository?
examples/dump.rs (line 297)
291fn print_strings(strings: &[StringFinding]) {
292    section(&format!("strings ({})", strings.len()));
293    for found in strings {
294        println!(
295            "  record #{} offset {} {:?}: {}",
296            found.record_index(),
297            found.offset(),
298            found.encoding(),
299            escape_inline(found.value())
300        );
301    }
302}
pub const fn encoding(&self) -> StringEncoding

Returns string encoding used for extraction.

Returns

The StringEncoding under which this string was extracted.

Examples found in repository?
examples/dump.rs (line 298)
291fn print_strings(strings: &[StringFinding]) {
292    section(&format!("strings ({})", strings.len()));
293    for found in strings {
294        println!(
295            "  record #{} offset {} {:?}: {}",
296            found.record_index(),
297            found.offset(),
298            found.encoding(),
299            escape_inline(found.value())
300        );
301    }
302}
pub fn value(&self) -> &str

Returns extracted string value.

Returns

The extracted string value.

Examples found in repository?
examples/dump.rs (line 299)
291fn print_strings(strings: &[StringFinding]) {
292    section(&format!("strings ({})", strings.len()));
293    for found in strings {
294        println!(
295            "  record #{} offset {} {:?}: {}",
296            found.record_index(),
297            found.offset(),
298            found.encoding(),
299            escape_inline(found.value())
300        );
301    }
302}